==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("MultiColumnComboBoxValueChangedEventArgs", () => new MultiColumnComboBoxValueChangedEventArgsDescription());
            a.z("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("MultiColumnComboBoxValueChangedEventArgs", () => new MultiColumnComboBoxValueChangedEventArgsDescription());
            a.ab("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
})();
